import { NgZone, Injector } from '@angular/core';
import { Observable } from 'rxjs';
import { database } from 'firebase';
import { NativeFirebaseDatabase } from './native-firebase';
import { DataSnapshot } from './reexports';
import { DataSnapshotObservable } from './observable/data-snapshot-observable';
import './observable/add/run-in-zone';
export declare type NativeDatabaseRef = database.Reference;
export declare type Query = database.Query;
export declare type EventType = 'value' | 'child_added' | 'child_changed' | 'child_removed' | 'child_moved';
export declare class Event {
    static Value: EventType;
    static ChildAdded: EventType;
    static ChildChanged: EventType;
    static ChildRemoved: EventType;
    static ChildMoved: EventType;
}
export declare class FirebaseQuery {
    protected _ref: NativeDatabaseRef;
    protected ngZone: NgZone;
    private query;
    protected wrappedRef: FirebaseDatabaseRef;
    readonly ref: FirebaseDatabaseRef;
    constructor(_ref: NativeDatabaseRef, ngZone: NgZone);
    orderByChild(child: string): FirebaseQuery;
    orderByKey(): FirebaseQuery;
    orderByPriority(): FirebaseQuery;
    orderByValue(): FirebaseQuery;
    startAt(value: number | string | boolean | null, key?: string): FirebaseQuery;
    endAt(value: number | string | boolean | null, key?: string): FirebaseQuery;
    equalTo(value: number | string | boolean | null, key?: string): FirebaseQuery;
    limitToFirst(limit: number): FirebaseQuery;
    limitToLast(limit: number): FirebaseQuery;
    once<T>(event: EventType): DataSnapshotObservable<T>;
    onceValue<T>(): DataSnapshotObservable<T>;
    onceChildAdded<T>(): DataSnapshotObservable<T>;
    onceChildChanged<T>(): DataSnapshotObservable<T>;
    onceChildMoved<T>(): DataSnapshotObservable<T>;
    onceChildRemoved<T>(): DataSnapshotObservable<T>;
    on<T>(event: EventType): DataSnapshotObservable<T>;
    onValue<T>(): DataSnapshotObservable<T>;
    onChildAdded<T>(): DataSnapshotObservable<T>;
    onChildChanged<T>(): DataSnapshotObservable<T>;
    onChildMoved<T>(): DataSnapshotObservable<T>;
    onChildRemoved<T>(): DataSnapshotObservable<T>;
    isEqual(query: FirebaseQuery): boolean;
    private getEventHandler(sub, complete?);
    private getQueryOrRef();
    private _call(fnName, ...args);
}
export declare class FirebaseDatabaseRefConfig {
    parent: FirebaseDatabaseRef;
    ref: NativeDatabaseRef;
    constructor(parent: FirebaseDatabaseRef, ref: NativeDatabaseRef);
}
export declare class FirebaseDatabaseRef extends FirebaseQuery {
    private config;
    private injector;
    static create(parent: FirebaseDatabaseRef, injector: Injector, ref: NativeDatabaseRef): any;
    readonly key: string | null;
    constructor(ngZone: NgZone, config: FirebaseDatabaseRefConfig, injector: Injector);
    child(path: string): FirebaseDatabaseRef;
    set(value: any): Observable<void>;
    setPriority(priority: string | number | null): Observable<void>;
    setWithPriority(newVal: any, priority: string | number | null): Observable<void>;
    push(value?: any): Observable<FirebaseDatabaseRef>;
    update(value: Object): Observable<void>;
    remove(): Observable<void>;
    transaction(transactionUpdate: (node: any) => any | never, applyLocally?: boolean): Observable<{
        committed: boolean;
        snapshot: DataSnapshot;
    }>;
}
export declare class FirebaseDatabase {
    private db;
    private injector;
    constructor(db: NativeFirebaseDatabase, injector: Injector);
    ref(path?: string): FirebaseDatabaseRef;
}
